@@ -457,10 +457,6 @@ class Order(BaseModel):
 
 
 def post_save_order_receiver(sender, instance, created, *args, **kwargs):
-
-    from .tasks import send_order_message
-    send_order_message.delay(instance.pk, created)
-
     from aparnik.packages.shops.vouchers.models import Voucher
     Voucher.objects.change_order(instance)
 
